# Perseus: Email Python Library

Perseus Email Python Library is a repository of reusable Python components to compose and send email.

These components have minimal dependencies on other libraries, so that they can be deployed easily.  In addition, these components will keep their interfaces as stable as possible, so that other Python projects can integrate these components without having to worry about changes in the future.


To install the Perseus Email Python Library, enter the follow command line:

```bash
$ pipenv install perseus-email-library
```
